@@ -16,7 +16,7 @@
 
 import os
 import sys
-from cl_utils import convertStrListDict, fillstr, getpathenv, runOsCommand,\
+from cl_utils import convertStrListDict, getpathenv, runOsCommand,\
                      pathJoin, _toUNICODE
 from cl_vars_share import varsShare as glob_attr
 import re
@@ -659,8 +659,8 @@ storage of variables templates")%location)
                 mlen_name, mlen_type, mlen_mode = getLenElements(varsDict)
             plist=varsDict.keys()
             plist.sort()
-            br = fillstr("-",mlen_name) + " " +\
-                fillstr("-",mlen_mode) + " " +  fillstr("-",10)
+            br = "-"*mlen_name + " " +\
+                 "-"*mlen_mode + " " +  "-"*10
             cl_overriding.printSUCCESS(title)
             cl_overriding.printSUCCESS(br)
             cl_overriding.printSUCCESS(\
