@@ -24,7 +24,7 @@ from cl_vars_share import varsShare, clLocale
 from os.path import exists as pathexists
 from os import path
 from cl_utils import isMount, genpassword, getAvailableX11Drivers, \
-                     listDirectory
+                     listDirectory,isPkgInstalled
 from encrypt import getHash
 
 class fillVars(varsShare):
@@ -440,14 +440,15 @@ class fillVars(varsShare):
             matchSect = re.search(r'Section "Device".*?EndSection',
                                   open('/etc/X11/xorg.conf').read(),re.S)
             if matchSect:
-                resDriver = re.search(r'Driver\s*"([^"]+)"',
+                resDriver = re.search(r'^\S*Driver\s*"([^"]+)"',
                                       matchSect.group(0),re.S)
                 if resDriver and resDriver.group(1) in list_avialable_drivers:
                     return resDriver.group(1)
 
         videoVal = self.getValueFromCmdLine("calculate","video")
         videoVal = {'i915':'intel'}.get(videoVal,videoVal)
-        if videoVal in list_avialable_drivers:
+        if not isPkgInstalled('xorg-server') or \
+            videoVal in list_avialable_drivers:
             return videoVal
         workedModules = map(lambda x:x[0],
                         filter(lambda x:x[1].isdigit() and int(x[1])>0,
