@@ -61,7 +61,7 @@ class clLocale:
                 'dumpkeys_charset':'',
                 'consolefont':'lat9w-16',
                 'xkblayout':'pt,us',
-                'language':'pt',
+                'language':'pt_BR',
         },
     #Canadian French
     'fr_CA' : {
@@ -135,6 +135,15 @@ class clLocale:
                 'xkblayout':'us,pl',
                 'language':'pl',
         },
+    #Portuguese
+    'pt_PT' : {
+                'locale':'pl_PL.UTF-8@euro',
+                'keymap':'pt-latin9',
+                'dumpkeys_charset':'',
+                'consolefont':'lat0-16',
+                'xkblayout':'pt,us',
+                'language':'pt',
+        },
     #Russian
     'ru_RU' : {
                 'locale':'ru_RU.UTF-8',
@@ -358,16 +367,17 @@ class varsShare:
         lineCompositeTmp = ""
         lineComposite = ""
         for line in confLines:
+            line = line.strip()
             if flagStartExtensions:
-                if 'EndSection' in line:
+                if line.startswith('EndSection'):
                     lineComposite = lineCompositeTmp
                     break
-                elif 'Section' in line:
+                elif line.startswith('Section'):
                     break
-                if 'Option' in line and '"Composite"' in line:
+                if line.startswith('Option') and '"Composite"' in line:
                     lineCompositeTmp = line
             else:
-                if '"Extensions"' in line and 'Section' in line:
+                if '"Extensions"' in line and line.startswith('Section'):
                     flagStartExtensions = True
         if lineComposite:
             listOpt = filter(lambda x: x.strip(), lineComposite.split('"'))
