@@ -14,7 +14,7 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-__version__ = "2.2.15"
+__version__ = "2.2.16"
 __app__ = "calculate-lib"
 
 import sys, os, stat, re
@@ -382,11 +382,6 @@ class updateSystemConfigs(shareUpdateConfigs):
         """Обновление системных конфигурационных файлов"""
         # флаг обновления и программы используемые для наложения шаблонов
         flagUpdate, mergePrograms = self.getFlagUpdAndInstPrograms()
-        # Проверка есть ли в пакете защищенные конфигурационные файлы
-        if not self.isExistsProtectFiles(configPath):
-            self.logger.info(_("Package %s") %nameProgram)
-            self.logger.warn(_("Not found protected files"))
-            return True
         self.logger.info(_("Package %s") %nameProgram)
         self.logger.info(_("Update system cofiguration files"))
         if not os.path.exists(configPath):
